@@ -52,7 +52,7 @@ def project(ctx, _project):  # pylint:disable=redefined-outer-name
     """Commands for projects."""
     if _project:
         Printer.print_warning(
-            "Passing arguments to command groups is deprecated and will be removed in v1.2! "
+            "Passing arguments to command groups is deprecated and will be removed in v2! "
             "Please use arguments on the sub-command directly: "
             "`polyaxon project SUB_COMMAND --help`"
         )
@@ -258,7 +258,7 @@ def delete(ctx, _project):
     try:
         polyaxon_client = ProjectClient(owner=owner, project=project_name)
         polyaxon_client.delete()
-        local_project = get_local_project()
+        local_project = get_local_project(is_cli=True)
         if local_project and (owner, project_name) == (
             local_project.owner,
             local_project.name,
