@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,12 @@
 
 import os
 
-from polyaxon.env_vars.keys import POLYAXON_KEYS_CONTEXT_ROOT
+from polyaxon.env_vars.keys import (
+    POLYAXON_KEYS_ARCHIVE_ROOT,
+    POLYAXON_KEYS_ARTIFACTS_ROOT,
+    POLYAXON_KEYS_CONTEXT_ROOT,
+    POLYAXON_KEYS_OFFLINE_ROOT,
+)
 
 
 def polyaxon_user_path():
@@ -28,10 +33,16 @@ def polyaxon_user_path():
 
 
 CONTEXT_ROOT = os.environ.get(POLYAXON_KEYS_CONTEXT_ROOT, "/plx-context")
+CONTEXT_MOUNT_GC = "{}/.gc/gc-secret.json".format(CONTEXT_ROOT)
 CONTEXT_MOUNT_CONFIGS = "{}/.configs".format(CONTEXT_ROOT)
-CONTEXT_MOUNT_AUTH = "{}/.polyaxonauth".format(CONTEXT_MOUNT_CONFIGS)
+CONTEXT_MOUNT_AUTH = "{}/.auth".format(CONTEXT_MOUNT_CONFIGS)
+CONTEXT_MOUNT_FILE_WATCHER = "{}/.fs".format(CONTEXT_ROOT)
 CONTEXT_MOUNT_ARTIFACTS = "{}/artifacts".format(CONTEXT_ROOT)
-CONTEXT_MOUNT_ARTIFACTS_FORMAT = "{}/artifacts/{{}}".format(CONTEXT_ROOT)
+CONTEXT_MOUNT_ARTIFACTS_FORMAT = "{}/{{}}".format(CONTEXT_MOUNT_ARTIFACTS)
+CONTEXT_MOUNT_ARTIFACTS_RELATED = CONTEXT_MOUNT_ARTIFACTS_FORMAT.format("_related_runs")
+CONTEXT_MOUNT_ARTIFACTS_RELATED_FORMAT = "{}/{{}}".format(
+    CONTEXT_MOUNT_ARTIFACTS_RELATED
+)
 CONTEXT_MOUNT_RUN_OUTPUTS_FORMAT = "{}/outputs".format(CONTEXT_MOUNT_ARTIFACTS_FORMAT)
 CONTEXT_MOUNT_RUN_EVENTS_FORMAT = "{}/events".format(CONTEXT_MOUNT_ARTIFACTS_FORMAT)
 CONTEXT_MOUNT_SHM = "/dev/shm"
@@ -39,5 +50,13 @@ CONTEXT_MOUNT_DOCKER = "/var/run/docker.sock"
 
 CONTEXT_TMP_POLYAXON_PATH = "/tmp/.polyaxon/"
 CONTEXT_USER_POLYAXON_PATH = polyaxon_user_path()
-CONTEXT_ARCHIVE_ROOT = "/tmp/plx/archives"
-CONTEXT_ARTIFACTS_ROOT = "/tmp/plx/artifacts"
+CONTEXT_ARCHIVE_ROOT = os.environ.get(POLYAXON_KEYS_ARCHIVE_ROOT, "/tmp/plx/archives")
+CONTEXT_ARTIFACTS_ROOT = os.environ.get(
+    POLYAXON_KEYS_ARTIFACTS_ROOT, "/tmp/plx/artifacts"
+)
+CONTEXT_OFFLINE_ROOT = os.environ.get(POLYAXON_KEYS_OFFLINE_ROOT, "/tmp/plx/offline")
+CONTEXT_OFFLINE_FORMAT = "{}/{{}}".format(CONTEXT_OFFLINE_ROOT)
+CONTEXT_ARTIFACTS_FORMAT = "{}/{{}}".format(CONTEXT_ARTIFACTS_ROOT)
+
+CONTEXTS_OUTPUTS_SUBPATH_FORMAT = "{}/outputs"
+CONTEXTS_EVENTS_SUBPATH_FORMAT = "{}/events"
