@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -37,7 +37,7 @@ def collect_dag_components(dag: V1Dag, path_context: str = None):
     """Collect components that cannot be resolved by the scheduler"""
     for op in dag.operations:
         op_name = op.name
-        if op.has_url_reference or op.has_path_reference:
+        if op.has_url_reference or op.has_path_reference or op.has_hub_reference:
             try:
                 op = collect_references(op, path_context)
             except Exception as e:
@@ -63,6 +63,7 @@ def collect_references(config: V1Operation, path_context: str = None):
                 os.path.dirname(os.path.abspath(path_context)), path_ref
             )
         component = ConfigSpec.get_from(path_ref).read()
+        path_context = path_ref
     else:
         raise PolyaxonfileError("Operation found without component")
 
@@ -81,7 +82,7 @@ def collect_references(config: V1Operation, path_context: str = None):
         )
     config.component = component
     if component.is_dag_run:
-        component.run.collect_components()
+        collect_dag_components(component.run, path_context)
     return config
 
 
