@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,17 +18,14 @@ import polyaxon_sdk
 
 from marshmallow import fields, validate
 
+from polyaxon.lifecycle import V1Statuses
 from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
 
 
-class V1NotificationTrigger(polyaxon_sdk.NotificationTrigger):
-    pass
-
-
 class NotificationSchema(BaseCamelSchema):
     connections = fields.List(fields.Str(), required=True)
     trigger = fields.Str(
-        allow_none=True, validate=validate.OneOf(V1NotificationTrigger.allowable_values)
+        allow_none=True, validate=validate.OneOf(V1Statuses.allowable_values)
     )
 
     @staticmethod
@@ -37,14 +34,20 @@ class NotificationSchema(BaseCamelSchema):
 
 
 class V1Notification(BaseConfig, polyaxon_sdk.V1Notification):
-    """You can configure Polyaxon to send notifications to users about event changes in the platform.
+    """You can configure Polyaxon to send notifications to users and systems
+    about event changes in your runs.
 
-    Polyaxon can send notifications when a runs reaches a final status:
+    Notifications also allow you to build or set up integrations using webhooks.
+    External systems can subscribe or provide handling for certain events.
+    When one of those events is triggered, Polyaxon will send an HTTP request
+    payload to the webhook's configured URL.
+
+    Polyaxon can send notifications when a run reaches a final status:
 
      * succeeded
      * failed
      * stopped
-     * done
+     * done (any final state)
 
      Args:
          connections: List[str]
@@ -61,10 +64,11 @@ class V1Notification(BaseConfig, polyaxon_sdk.V1Notification):
     ## Python usage
 
     ```python
-    >>> from polyaxon.polyflow import V1Notification, V1NotificationTrigger
+    >>> from polyaxon.lifecycle import V1Statuses
+    >>> from polyaxon.polyflow import V1Notification
     >>> notification = V1Notification(
     >>>     connections=["slack-connection", "discord-connection"],
-    >>>     trigger=V1NotificationTrigger.FAILED,
+    >>>     trigger=V1Statuses.FAILED,
     >>> )
     ```
 
@@ -98,3 +102,7 @@ class V1Notification(BaseConfig, polyaxon_sdk.V1Notification):
         "connections",
         "trigger",
     ]
+
+    def to_operator(self):
+        self.trigger = self.trigger.capitalize()
+        return super().to_dict()
