@@ -133,7 +133,7 @@ class V1Operation(BaseOp, TemplateMixinConfig, polyaxon_sdk.V1Operation):
         dependencies: [dependencies](/docs/automation/flow-engine/flow-dependencies/#dependencies), optional  # noqa
         trigger: [trigger](/docs/automation/flow-engine/flow-dependencies/#trigger), optional
         conditions: [conditions](/docs/core/scheduling-strategies/conditional-scheduling/#conditional-scheduling), optional  # noqa
-        skip_on_upstream_skip: [skip_on_upstream_skip](/docs/automation/flow-engine/flow-dependencies/skiponupstreamskip/), optional  # noqa
+        skip_on_upstream_skip: [skip_on_upstream_skip](/docs/automation/flow-engine/flow-dependencies/#skiponupstreamskip), optional  # noqa
         run_patch: Dict, optional
         hub_ref: str, optional
         dag_ref: str, optional
@@ -258,7 +258,7 @@ class V1Operation(BaseOp, TemplateMixinConfig, polyaxon_sdk.V1Operation):
     ```
 
     > **Note**: Please check this
-    > [in-depth section about presets](/docs/core/scheduling-strategies/presets/).
+    > [in-depth section about presets](/docs/core/scheduling-presets/).
 
     ### name
 
@@ -306,7 +306,7 @@ class V1Operation(BaseOp, TemplateMixinConfig, polyaxon_sdk.V1Operation):
 
     ### queue
 
-    The [queue](/docs/core/scheduling-strategies/queue-routing/) to use for this operation run,
+    The [queue](/docs/core/scheduling-strategies/queues/) to use for this operation run,
     if provided, it will override the component's queue otherwise
     the queue of the component will be used if it exists.
 
@@ -538,6 +538,16 @@ class V1Operation(BaseOp, TemplateMixinConfig, polyaxon_sdk.V1Operation):
     ```yaml
     >>> isApproved: false
     ```
+
+    ### Cost
+
+    A field to define the cost of running the operation, the value is a float and should map to a
+    convention of a cost estimation in your team or
+    it can map directly to the cost of using the environment where the operation is running.
+
+    ```yaml
+    >>> cost: 2.2
+    ```
     """
 
     SCHEMA = OperationSchema
