@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -55,8 +55,8 @@ class V1Dask(BaseConfig, polyaxon_sdk.V1Dask):
     [Dask cluster](https://kubernetes.dask.org/en/latest/).
 
     > Dask Kubernetes deploys Dask workers on Kubernetes clusters using native Kubernetes APIs.
-      It is designed to dynamically launch short-lived deployments of workers
-      during the lifetime of a Python process.
+    > It is designed to dynamically launch short-lived deployments of workers
+    > during the lifetime of a Python process.
 
     The Dask job spawn a temporary adaptive Dask cluster with a
     Dask scheduler and workers to run your container.
@@ -71,10 +71,9 @@ class V1Dask(BaseConfig, polyaxon_sdk.V1Dask):
         environment: [V1Environment](/docs/core/specification/environment/), optional
         connections: List[str], optional
         volumes: List[[Kubernetes Volume](https://kubernetes.io/docs/concepts/storage/volumes/)],
-                 optional
+             optional
         init: List[[V1Init](/docs/core/specification/init/)], optional
-        sidecars: List[[sidecar containers](/docs/core/specification/sidecars/)],
-                  optional
+        sidecars: List[[sidecar containers](/docs/core/specification/sidecars/)], optional
         container: [Kubernetes Container](https://kubernetes.io/docs/concepts/containers/)
 
     ## YAML usage
@@ -239,7 +238,7 @@ class V1Dask(BaseConfig, polyaxon_sdk.V1Dask):
     >>>   volumes:
     >>>     - name: volume1
     >>>       persistentVolumeClaim:
-    >>>       claimName: pvc1
+    >>>         claimName: pvc1
     >>>   ...
     >>>   container:
     >>>     name: myapp-container
