@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,6 @@
 
 from typing import Dict, Iterable, List, Optional
 
-from polyaxon.containers.names import MAIN_JOB_CONTAINER
 from polyaxon.exceptions import PolypodException
 from polyaxon.k8s import k8s_schemas
 from polyaxon.polyflow import V1Init
@@ -34,6 +33,7 @@ from polyaxon.utils.list_utils import to_list
 
 
 def get_main_container(
+    container_id: str,
     main_container: k8s_schemas.V1Container,
     volume_mounts: List[k8s_schemas.V1VolumeMount],
     contexts: PluginsContextsSpec,
@@ -58,9 +58,12 @@ def get_main_container(
     if artifacts_store and not run_path:
         raise PolypodException("Run path is required for main container.")
 
-    if artifacts_store and not contexts.collect_artifacts:
+    if artifacts_store and (
+        not contexts.collect_artifacts or contexts.mount_artifacts_store
+    ):
         if artifacts_store.name not in connection_by_names:
             connection_by_names[artifacts_store.name] = artifacts_store
+        if artifacts_store.name not in connections:
             connections.append(artifacts_store.name)
 
     requested_connections = [connection_by_names[c] for c in connections]
@@ -87,6 +90,7 @@ def get_main_container(
         contexts=contexts,
         log_level=log_level,
         kv_env_vars=kv_env_vars,
+        artifacts_store_name=artifacts_store.name if artifacts_store else None,
         connections=requested_connections,
         secrets=requested_secrets,
         config_maps=requested_config_maps,
@@ -104,7 +108,7 @@ def get_main_container(
 
     return patch_container(
         container=main_container,
-        name=MAIN_JOB_CONTAINER,
+        name=container_id,
         env=env,
         env_from=env_from,
         volume_mounts=volume_mounts,
