@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,14 +20,13 @@ from marshmallow import fields
 
 from polyaxon.schemas.base import BaseCamelSchema
 from polyaxon.schemas.fields.ref_or_obj import RefOrObject
+from polyaxon.schemas.fields.str_or_list import StrOrList
 from polyaxon.schemas.types.base import BaseTypeConfig
 
 
 class ArtifactsTypeSchema(BaseCamelSchema):
-    connection = RefOrObject(fields.Str(allow_none=True))
-    files = RefOrObject(fields.List(fields.Str(), allow_none=True))
-    dirs = RefOrObject(fields.List(fields.Str(), allow_none=True))
-    init = RefOrObject(fields.Bool(allow_none=True))
+    files = RefOrObject(fields.List(StrOrList(), allow_none=True))
+    dirs = RefOrObject(fields.List(StrOrList(), allow_none=True))
     workers = RefOrObject(fields.Int(allow_none=True))
 
     @staticmethod
@@ -45,16 +44,16 @@ class V1ArtifactsType(BaseTypeConfig, polyaxon_sdk.V1ArtifactsType):
 
 
     Args:
-        connection: str, optional, the connection to use,
-                    if not provided the default artifacts store is used
-        files: List[str], optional, list of file subpaths
-        dirs: List[str], optional, list of directory subpaths
-        init: bool, optional, if True the files and the dirs will be automatically
-              downloaded/provided in the run's artifacts context.
+        files: Union[List[str], List[[str, str]], optional,
+             list of file subpaths or a list of [path from, path to].
+        dirs: Union[List[str], List[[str, str]], optional,
+             list of directory subpaths or a list of [path from, path to].
         workers: int, optional, number of threads for downloading data from S3/GCS/Azure.
 
     ### YAML usage
 
+    ### Usage in IO and params definition
+
     The inputs definition
 
     ```yaml
@@ -72,22 +71,48 @@ class V1ArtifactsType(BaseTypeConfig, polyaxon_sdk.V1ArtifactsType):
     ```yaml
     >>> params:
     >>>   some-file-names: {value: {files: ["file1", "/path/to/file2"]}}
-    >>>   tensorboard-log-dir: {value: {dirs: ["/tensorboard-logs"], connection: "foo", init: True}}
-    >>>   dataset1: {value: {connection: "s3-dataset", init: True}}
+    >>>   custom-file-paths: {value: {files: [["file1", "to/this/path/file1"], "/path/to/file2"]}}
+    >>>   tensorboard-log-dir: {value: {dirs: ["/tensorboard-logs"]}, connection: "foo", toInit: True}
+    >>>   dataset1: {value: {value: {dirs: ["/"]}, connection: "s3-dataset", init: True}
     ```
 
     The first param will be just a list of files definition that
     the user should know how to handle in their program.
 
     The second param, Polyaxon will load only that directory path from connection "foo".
-    This connection could be any bycket or volume.
+    This connection could be any a bucket or a volume.
 
     In the third param, `dataset1` will be resolved automatically because
     Polyaxon knows about that connection and that it's of type S3.
     It will load all data in that S3 bucket before starting the experiment.
 
+    ### Usage in initializers
+
+    ```yaml
+    >>> version:  1.1
+    >>> kind: component
+    >>> run:
+    >>>   kind: job
+    >>>   init:
+    >>>   - artifacts:
+    >>>       files: ["file1", "/path/to/file2"]
+    >>>   - artifacts:
+    >>>       files: [["file1", "to/this/path/file1"], "/path/to/file2"]
+    >>>   - artifacts:
+    >>>       dirs: ["/tensorboard-logs"]
+    >>>     connection: foo
+    >>>   - artifacts:
+    >>>       dirs: ["/"]
+    >>>     connection: s3-datase
+    >>>
+    >>>   container:
+    >>>     ...
+    ```
+
     ### Python usage
 
+    ### Usage in IO and params definition
+
     The inputs definition
 
     ```python
@@ -97,15 +122,15 @@ class V1ArtifactsType(BaseTypeConfig, polyaxon_sdk.V1ArtifactsType):
     >>> inputs = [
     >>>     V1IO(
     >>>         name="some-file-names",
-    >>>         iotype=types.ARTIFACTS,
+    >>>         type=types.ARTIFACTS,
     >>>     ),
     >>>     V1IO(
     >>>         name="tensorboard-log-dir",
-    >>>         iotype=types.ARTIFACTS,
+    >>>         type=types.ARTIFACTS,
     >>>     ),
     >>>     V1IO(
     >>>         name="dataset1",
-    >>>         iotype=types.ARTIFACTS,
+    >>>         type=types.ARTIFACTS,
     >>>     )
     >>> ]
     ```
@@ -119,15 +144,45 @@ class V1ArtifactsType(BaseTypeConfig, polyaxon_sdk.V1ArtifactsType):
     >>> params = {
     >>>     "test1": V1Param(value=types.V1ArtifactsType(files=["file1", "/path/to/file2"])),
     >>>     "test2": V1Param(
-    >>>         value=types.V1ArtifactsType(dirs=["/tensorboard-logs"], connection="foo", init=True)
+    >>>         value=types.V1ArtifactsType(dirs=["/tensorboard-logs"]),
+    >>>         connection="foo",
+    >>>         to_init=True
     >>>     ),
     >>>     "test3": V1Param(
-    >>>         value=types.V1ArtifactsType(connection="s3-dataset", init=True, workers=10)
+    >>>         value=types.V1ArtifactsType(dirs=["/"], workers=10),
+    >>>         connection="s3-dataset",
+    >>>         to_init=True
     >>>     ),
     >>> }
     ```
+
+    ### Usage in initializers
+
+    ```python
+    >>> from polyaxon.polyflow import V1Component, V1Init, V1Job
+    >>> from polyaxon.schemas.types import V1ArtifactsType
+    >>> from polyaxon.k8s import k8s_schemas
+    >>> component = V1Component(
+    >>>     run=V1Job(
+    >>>        init=[
+    >>>             V1Init(
+    >>>                 artifacts=V1ArtifactsType(files=["file1", "/path/to/file2"])
+    >>>             ),
+    >>>             V1Init(
+    >>>                 artifacts=V1ArtifactsType(dirs=["/tensorboard-logs"]),
+    >>>                 connection="foo"
+    >>>             ),
+    >>>             V1Init(
+    >>>                 artifacts=V1ArtifactsType(dirs=["/"], workers=10),
+    >>>                 connection="s3-dataset"
+    >>>             ),
+    >>>        ],
+    >>>        container=k8s_schemas.V1Container(...)
+    >>>     )
+    >>> )
+    ```
     """
 
     IDENTIFIER = "artifacts"
     SCHEMA = ArtifactsTypeSchema
-    REDUCED_ATTRIBUTES = ["files", "dirs", "connection", "init", "workers"]
+    REDUCED_ATTRIBUTES = ["files", "dirs", "workers"]
