@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -70,11 +70,11 @@ class V1AuthType(BaseTypeConfig, polyaxon_sdk.V1AuthType):
     >>> inputs = [
     >>>     V1IO(
     >>>         name="test1",
-    >>>         iotype=types.AUTH,
+    >>>         type=types.AUTH,
     >>>     ),
     >>>     V1IO(
     >>>         name="test2",
-    >>>         iotype=types.AUTH,
+    >>>         type=types.AUTH,
     >>>     ),
     >>> ]
     ```
