@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +13,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+import os
 
 import polyaxon_sdk
 
 from marshmallow import fields
 
-from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
+from polyaxon.schemas.base import BaseCamelSchema
 from polyaxon.schemas.fields.ref_or_obj import RefOrObject
+from polyaxon.schemas.types.base import BaseTypeConfig
 
 
 class GcsTypeSchema(BaseCamelSchema):
@@ -31,7 +33,7 @@ class GcsTypeSchema(BaseCamelSchema):
         return V1GcsType
 
 
-class V1GcsType(BaseConfig, polyaxon_sdk.V1GcsType):
+class V1GcsType(BaseTypeConfig, polyaxon_sdk.V1GcsType):
     """GCS type.
 
     Args:
@@ -69,11 +71,11 @@ class V1GcsType(BaseConfig, polyaxon_sdk.V1GcsType):
     >>> inputs = [
     >>>     V1IO(
     >>>         name="test1",
-    >>>         iotype=types.GCS,
+    >>>         type=types.GCS,
     >>>     ),
     >>>     V1IO(
     >>>         name="test2",
-    >>>         iotype=types.GCS,
+    >>>         type=types.GCS,
     >>>     ),
     >>> ]
     ```
@@ -94,3 +96,15 @@ class V1GcsType(BaseConfig, polyaxon_sdk.V1GcsType):
     IDENTIFIER = "gcs"
     SCHEMA = GcsTypeSchema
     REDUCED_ATTRIBUTES = ["bucket", "blob"]
+
+    def __str__(self):
+        path = "gs://{}".format(self.bucket)
+        if self.blob:
+            path = os.path.join(path, self.blob)
+        return path
+
+    def __repr__(self):
+        return str(self)
+
+    def to_param(self):
+        return str(self)
